==> 1.0.5.tar.gz: ios/Classes/FLHyperSnapSDK.swift <==
//
//  FLHyperSnapSDK.swift
//


import Foundation
import HyperSnapSDK

public class FLHyperSnapSDK {
    static var INITIALIZE = "initialize";
    static var INITIALIZE_WITH_TOKEN = "initializeWithToken";
    static var SET_SHOULD_ENABLE_SSL_PINNING =
        "setShouldEnableSSLPinning";
    static var SET_SHOULD_USE_SIGNATURE = "setShouldUseSignature";
    static var SET_HTTPS_TIMEOUT_VALUES = "setHttpTimeoutValues";
    static var SORT_JSON_KEYS_ALPHABETICALLY =
        "sortJSONKeysAlphabetically";
    static var SET_SHOULD_RETURN_RAW_RESPONSE =
        "setShouldReturnRawResponse";
    static var START_USER_SESSION = "startUserSession";
    static var END_USER_SESSION = "endUserSession";
    static func initialize(appId: String, appName: String, regionValue: String) {
        let regionParams = regionValue.components(separatedBy: ".")
        
        let region = getHVHyperSnapParam(enumClass: regionParams[0], param: regionParams[1], type: HyperSnapParams.Region.self)
        HyperSnapSDKConfig.initialize(appId: appId, appKey: appName, region: region )
    }
    static func initializeWithToken(appId: String, accessToken: String, regionValue: String) {
        let regionParams = regionValue.components(separatedBy: ".")
        
        let region = getHVHyperSnapParam(enumClass: regionParams[0], param: regionParams[1], type: HyperSnapParams.Region.self)
        HyperSnapSDKConfig.initialize(appId: appId, accessToken: accessToken, region: region )
    }
    static func setShouldUseSignature(_ shouldUseSignature : Bool){
        HyperSnapSDKConfig.setShouldUseSignature(shouldUseSignature)
    }
    
    static func setShouldEnableSSLPinning(_ shouldEnableSSLPinning : Bool){
        HyperSnapSDKConfig.setShouldEnableSSLPinning(shouldEnableSSLPinning)
    }
    
    static func setShouldUseAnalytics(_ shouldUse: Bool){
        HyperSnapSDKConfig.setShouldUseAnalytics(shouldUse)
    }
    
    static func setTimeoutIntervalForRequest(_ timeout: Double){
        HyperSnapSDKConfig.setTimeoutIntervalForRequest(timeout)
    }
    
    static func setShouldReturnRawResponse(_ shouldReturn : Bool){
        HyperSnapSDKConfig.setShouldReturnRawResponse(shouldReturn)
    }
    
    
    static func sortDictionaryAlphabetically(_ dictionary : [String:AnyObject])-> String {
        return HyperSnapSDKConfig.sortDictionaryAlphabetically(dictionary)
    }
    
    
    static func startUserSession(userID: String) -> HVError?{
        if(userID.isEmpty){
            return HyperSnapSDKConfig.startUserSession()
            
        } else {
            return HyperSnapSDKConfig.startUserSession(userID)
            
        }
    }
    
    
    static func endUserSession() {
        HyperSnapSDKConfig.endUserSession()
    }
    
    static func getHVHyperSnapParam<T>(enumClass: String, param: String, type: T.Type) -> T {
        switch param {
        case "India":
            return HyperSnapParams.Region.India as! T
        case "AsiaPacific":
            return HyperSnapParams.Region.AsiaPacific as! T
        case "UnitedStates":
            return HyperSnapParams.Region.UnitedStates as! T
        default:
            return HyperSnapParams.Region.India as! T
        }
        
        //        switch enumClass {
        //        case "Product":
        //            return NSClassFromString("HyperSnapParams.Product.\(param)") as! T
        //        case "Region":
        //            let member = "\(param)"
        //            return HyperSnapParams.Region.member as! T
        //        case "Document":
        //            return NSClassFromString("HVDocConfig.Document.\(param)") as! T
        //        case "LivenessMode":
        //            return NSClassFromString("HVFaceConfig.LivenessMode.\(param)") as! T
        //        default:
        //            return NSClassFromString("HyperSnapParams.Region.\(param)") as! T
        //        }
    }
}

==> 1.1.0.tar.gz: ios/Classes/FLHyperSnapSDK.swift <==
//
//  FLHyperSnapSDK.swift
//


import Foundation
import HyperSnapSDK

public class FLHyperSnapSDK {
    static var INITIALIZE = "initialize";
    static var INITIALIZE_WITH_TOKEN = "initializeWithToken";
    static var SET_SHOULD_ENABLE_SSL_PINNING =
    "setShouldEnableSSLPinning";
    static var SET_SHOULD_USE_SIGNATURE = "setShouldUseSignature";
    static var SET_HTTPS_TIMEOUT_VALUES = "setHttpTimeoutValues";
    static var SORT_JSON_KEYS_ALPHABETICALLY =
    "sortJSONKeysAlphabetically";
    static var SET_SHOULD_RETURN_RAW_RESPONSE =
    "setShouldReturnRawResponse";
    static var START_USER_SESSION = "startUserSession";
    static var END_USER_SESSION = "endUserSession";
    static func initialize(appId: String, appName: String, regionValue: String) {
        let regionParams = regionValue.components(separatedBy: ".")
        
        let region = getHVHyperSnapParam(enumClass: regionParams[0], param: regionParams[1], type: HyperSnapParams.Region.self)
        HyperSnapSDKConfig.initialize(appId: appId, appKey: appName, region: region )
    }
    static func initializeWithToken(appId: String, accessToken: String, regionValue: String) {
        let regionParams = regionValue.components(separatedBy: ".")
        
        let region = getHVHyperSnapParam(enumClass: regionParams[0], param: regionParams[1], type: HyperSnapParams.Region.self)
        HyperSnapSDKConfig.initialize(appId: appId, accessToken: accessToken, region: region )
    }
    static func setShouldUseSignature(_ shouldUseSignature : Bool){
        HyperSnapSDKConfig.setShouldUseSignature(shouldUseSignature)
    }
    
    static func setShouldEnableSSLPinning(_ shouldEnableSSLPinning : Bool){
        HyperSnapSDKConfig.setShouldEnableSSLPinning(shouldEnableSSLPinning)
    }
    
    static func setShouldUseAnalytics(_ shouldUse: Bool){
        HyperSnapSDKConfig.setShouldUseAnalytics(shouldUse)
    }
    
    static func setTimeoutIntervalForRequest(_ timeout: Double){
        HyperSnapSDKConfig.setTimeoutIntervalForRequest(timeout)
    }
    
    static func setShouldReturnRawResponse(_ shouldReturn : Bool){
        HyperSnapSDKConfig.setShouldReturnRawResponse(shouldReturn)
    }
    
    
    static func sortDictionaryAlphabetically(_ dictionary : [String:AnyObject])-> String {
        return HyperSnapSDKConfig.sortDictionaryAlphabetically(dictionary)
    }
    
    
    static func startUserSession(userID: String?) -> HVSessionResponse{
        if let userID = userID {
            if (userID.isEmpty){
                return HyperSnapSDKConfig.startUserSession()
            } else {
                return HyperSnapSDKConfig.startUserSession(userID)
            }
        } else {
            return HyperSnapSDKConfig.startUserSession()
        }
    }
    
    
    static func endUserSession() {
        HyperSnapSDKConfig.endUserSession()
    }
    
    static func getHVHyperSnapParam<T>(enumClass: String, param: String, type: T.Type) -> T {
        switch param {
        case "India":
            return HyperSnapParams.Region.India as! T
        case "AsiaPacific":
            return HyperSnapParams.Region.AsiaPacific as! T
        case "UnitedStates":
            return HyperSnapParams.Region.UnitedStates as! T
        case "Africa":
            return HyperSnapParams.Region.Africa as! T
        default:
            return HyperSnapParams.Region.India as! T
        }
        
        //        switch enumClass {
        //        case "Product":
        //            return NSClassFromString("HyperSnapParams.Product.\(param)") as! T
        //        case "Region":
        //            let member = "\(param)"
        //            return HyperSnapParams.Region.member as! T
        //        case "Document":
        //            return NSClassFromString("HVDocConfig.Document.\(param)") as! T
        //        case "LivenessMode":
        //            return NSClassFromString("HVFaceConfig.LivenessMode.\(param)") as! T
        //        default:
        //            return NSClassFromString("HyperSnapParams.Region.\(param)") as! T
        //        }
    }
}
